/* dialog.cpp
 *
 * Pieter Eendebak <pte@ddsw.nl>
 *
 */

#include "includes.h"
#include "defines.h"

#include "dialog.moc"
#include "kfortune.h"

/* ##########################
 * #    class Misc          #
 * ##########################
 */

Misc::Misc ( int _launch, int _off, int _autoexit,
		int _time, int _choose, int _display,
		int _buttons,	
		QWidget *parent, const char *name )
                : QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);
	setMinimumSize(200,200);

	const int breed=300;
	const int hoog=410;
	const int bbreed=breed-20;
	const int bhoog=hoog-60;

	/* should be removed when resizing is ok */
	setFixedSize(breed, hoog);

	box = new QGroupBox( i18n("Misc options"), this, "box");

	/* create all the widgets */
	displayBox = new QCheckBox( i18n("Hide menubar"),
		box ) ;
	displayBox->setChecked( _display==USE_DISPLAY );
	buttonsBox = new QCheckBox( i18n("Show buttons"),
		box ) ;
	buttonsBox->setChecked( _buttons==USE_BUTTONS );
	offensiveBox = new QCheckBox( i18n
		("Show offensive fortunes"),
		 box, "offensive" );
	offensiveBox->setChecked( _off==USE_OFFENSIVE );

	choosingBox = new QCheckBox(
		i18n("Every fortune has same chance"), box );
	choosingBox->setChecked( _choose==CHOOSING_NORMAL );

	launchBox = new QCheckBox( klocale->translate
		("Launch KFortune on startup"),
		 box, "launch" );
	launchBox->setChecked( _launch==USE_AUTOLAUNCH );

	autoexitBox = new QCheckBox(
		klocale->translate("Automaticaly exit?"), box);
	autoexitBox->setChecked( _autoexit==USE_AUTOEXIT );

	time = new QLabel( klocale->translate("Exit after how many seconds?"),
				box);	
	scroll = new QScrollBar(3, 60, 5, 1, _time, QScrollBar::Horizontal,
					 box, "scroll");
	counter = new QLabel ( "", box, "counter");
	changeTime( _time ) ;

	bool btest = ( _autoexit == USE_AUTOEXIT );
	autoexitBox->setChecked(btest);
	scroll->setEnabled(btest);

	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	cancel = new QPushButton(klocale->translate("Cancel"), this, "cancel");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );
	connect(cancel, SIGNAL(clicked()), this, SLOT(reject()) );

	/* place all the widgets somewhere in the widget */
	box->setGeometry(10,10, bbreed, bhoog);

	int offset=20 ;

	displayBox->setGeometry( 10, offset, bbreed-20, 30 ) ;
	offset+=40 ;
	buttonsBox->setGeometry( 10, offset, bbreed-20, 30 ) ;
	offset+=40 ;
	offensiveBox->setGeometry ( 10, offset, bbreed-20, 30 );
	offset+=40 ;
	choosingBox->setGeometry(10, offset, bbreed-20, 30 );
	offset+=40 ;

	launchBox->setGeometry ( 10, offset, bbreed-20, 30 );
	offset+=40 ;
	autoexitBox->setGeometry( 10, offset, bbreed-20, 30 );
	offset+=30;
	connect(autoexitBox, SIGNAL(toggled(bool) ),
		 	this, SLOT(changeAutoexitBox(bool)) );
	time->setGeometry( 10, offset, bbreed-70, 25);
	counter->setGeometry( bbreed-50, offset, 40, 25 );
	offset+=35 ;
	scroll->setGeometry( 10, offset, bbreed-20, 14);
	connect(scroll, SIGNAL(valueChanged(int)),
		this, SLOT(changeTime(int)) );

 	ok->setGeometry(breed-160, hoog-40, 70, 30);
	cancel->setGeometry(breed-80, hoog-40, 70, 30);
}

Misc::~Misc()
{
	delete choosingBox;
	delete buttonsBox;
	delete launchBox;
	delete offensiveBox;
	delete autoexitBox;
	delete time;
	delete scroll;
	delete counter;
	delete box;

	delete ok;
	delete cancel;
}

void Misc::changeTime(int t)
{
	tijd = t;
	counter->setNum(t);
}

void Misc::changeAutoexitBox(bool s)
{
	scroll->setEnabled(s);
}

void Misc::display( int b )
{
	if( b==USE_DISPLAY )
		displayBox->setChecked( true ) ;
	else	displayBox->setChecked( false ) ;
}

int Misc::display()
{
	if ( displayBox->isChecked() )
		return USE_DISPLAY ;
	else	return NO_DISPLAY ;
}

void Misc::buttons( int b )
{
	if( b==USE_BUTTONS )
		buttonsBox->setChecked( true ) ;
	else	buttonsBox->setChecked( false ) ;
}

int Misc::buttons()
{
	if ( buttonsBox->isChecked() )
		return USE_BUTTONS ;
	else	return NO_BUTTONS ;
}

void Misc::launch( int b )
{
	launchBox->setChecked( b ) ;
}

int Misc::launch()
{
	return launchBox->isChecked() ;
}

void Misc::offensive( int b )
{
	offensiveBox->setChecked( b ) ;
}

int Misc::offensive()
{
	return offensiveBox->isChecked() ;
}

void Misc::choosing( int b )
{
	choosingBox->setChecked( b ) ;
}

int Misc::choosing()
{
	if ( choosingBox->isChecked() )
		return CHOOSING_NORMAL ;
	else	return CHOOSING_SIMPLE ;
}

void Misc::autoexit( int b )
{
	if ( b==USE_AUTOEXIT )
		autoexitBox->setChecked(true) ;
	else	autoexitBox->setChecked(false) ;
}

int Misc::autoexit()
{
	if ( autoexitBox->isChecked() )
		return USE_AUTOEXIT ;
	else	return NO_AUTOEXIT ;
}

/* ##########################
 * #    class DataBase      #
 * ##########################
 */

DataBase::DataBase ( int off, KConfig * conf, QWidget *parent, const char *name )
                : QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);
	setMinimumSize(300,450);
	const int breed=350;
	const int hoog=500;
	const int bbreed=breed-20;
	const int bhoog=hoog-60;
	// should be resizable
	setFixedSize(breed, hoog);

	box = new QGroupBox(
		klocale->translate("Configure database"), this, "box");
	
	naam = new QLabel(klocale->translate("Database"), box);
	number = new QLabel(klocale->translate("Number of fortunes"), box);

	QString p, q, r, filename, basedir;
	basedir.sprintf("%s", (conf->readEntry("datadir")).data() );
	DataFile h("", "", this, 0);

	conf->setGroup("DataBase");
	int x = conf->readNumEntry("database");

	rows = new QCheckBox *[x];
	rownumbers = new QLabel *[x];
	
	int i;
	for (i=0;i<x;i++)
	{
		p.setNum(i);
		filename = conf->readEntry( p.data() );

		p.append("off");
		if( conf->readNumEntry( p.data() )==1 )
		{

			// this is some VERY strange code,
			// but otherwise the program segfaults...
			r.sprintf("%s", filename.data() );
			r.append(" [offensive] ");

			p.setNum(i);
			rows[i] = new QCheckBox ( r.data(),
					box,
					p.data() );
			
			if ( off!=1)
			{	
				// we don't want offensive fortunes...	
				rows[i]->setEnabled(false);
				rows[i]->setChecked(false);
			}
			else
			{
				p.append("enabled");
				if ( conf->readNumEntry (p.data())==1)
				{
					rows[i]->setChecked(true);
				}
				else	rows[i]->setChecked(false);



			}
		}
		else
		{
			p.setNum(i);

			rows[i] = new QCheckBox ( filename.data(),
					box,
					p.data() );
		
			p.append("enabled");
			if (conf->readNumEntry(p.data())==1)
			{
				rows[i]->setChecked(true);
			}
			else	rows[i]->setChecked(false);  
		}

		p.sprintf("%s", (conf->readEntry("datadir")).data() );
		h.setName( p.data(), filename.data() );
		r.setNum( h.getNumber() );
	
		rownumbers[i] = new QLabel( r.data(), box);
	}

	label = new QLabel("Note :\n"
		"\nAdding you're own database is not"
		"\npossible at the moment.",
		box );

	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	cancel = new QPushButton(klocale->translate("Cancel"), this, "cancel");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );
	connect(cancel, SIGNAL(clicked()), this, SLOT(reject()) );

	// Resizing...

	int split = bbreed/2;

	box->setGeometry(10,10, bbreed, bhoog);

	naam->setGeometry(10, 20, split-10, 25);
	number->setGeometry(split+10, 20, bbreed-split-15, 25);

	for(i=0;i<x;i++)
	{
		rows[i]->setGeometry(10, 50+i*25, split-20, 20);
		rownumbers[i]->setGeometry(split+10, 50+i*25,
			 bbreed-split-15, 20 );
	}
	
	label->setGeometry(10, bhoog-100, bbreed-20, 85);
	
	ok->setGeometry(breed-160, hoog-40, 70, 30);
	cancel->setGeometry(breed-80, hoog-40, 70, 30);

}

DataBase::~DataBase()
{

	delete naam;
	delete number;
	
	delete [] rows;
	delete [] rownumbers;
	delete label;
	delete box;

	delete ok;
	delete cancel;
}

/*##################################
 *#	class About		 	#
 *##################################
 */

About::About( QPixmap *icon, QWidget *parent, const char *name)
	: QDialog( parent, name, TRUE )
{
	setCaption(CAPTION);
	
	// create the widgets
	
	QFrame *f = new QFrame(this);
	f->setLineWidth(1);
	f->setFrameStyle( QFrame::HLine | QFrame::Sunken );

	QString tmp;
	tmp.sprintf(
    "%s version %s (%s),\n\n"
    "Copyright (C) 1998 Pieter Eendebak\n"
    "%s comes with ABSOLUTELY NO WARRANTY;\n"
    "for details see the file COPYING.\n",
		NAME, VERSION, DATE, NAME);

	QLabel *pic = new QLabel(this);
	pic->setPixmap( *icon );

	QLabel *label = new QLabel( tmp.data(), this );
	label->setText( tmp.data() );
	label->setAlignment( AlignVCenter );

	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );

	QSize s1 = pic->sizeHint();
	QSize s2 = label->sizeHint();

	int breed= s1.width() + s2.width() + 30;
	int hoog = ( s1.height()>s2.height() + 40 ?
		s1.height():s2.height() ) + 40;

	pic->setGeometry( 10, (hoog-s1.height())/2,
		s1.width(), s1.height() );
 	label->setGeometry( 20+s1.width(), 30,
 		s2.width(), s2.height() );
 	f->setGeometry( 20+s1.width(), s2.height() + 40,
			s2.width(), 4);

	const int BR = 45 ;
	ok->setGeometry( breed - s2.width()/2 - 10 - BR,
		 s2.height() + 60, 2*BR, 30);
	
	f->show();
	pic->show();
	label->show();
	ok->show();

	move( 100, 100 ) ;
	resize( breed, hoog ) ;
	// setFixedSize(breed, hoog);
}

About::~About()
{
	delete ok;
}
	
